@@ -8,13 +8,11 @@ from ..utils import get_page_layout, get_text_objects
 class BaseParser(object):
     """Defines a base parser.
     """
-    def _generate_layout(self, filename):
+    def _generate_layout(self, filename, layout_kwargs):
         self.filename = filename
+        self.layout_kwargs = layout_kwargs
         self.layout, self.dimensions = get_page_layout(
-            self.filename,
-            char_margin=self.char_margin,
-            line_margin=self.line_margin,
-            word_margin=self.word_margin)
+            filename, **layout_kwargs)
         self.horizontal_text = get_text_objects(self.layout, ltype="lh")
         self.vertical_text = get_text_objects(self.layout, ltype="lv")
         self.pdf_width, self.pdf_height = self.dimensions
