@@ -50,10 +50,13 @@ class Lattice(BaseParser):
     flag_size : bool, optional (default: False)
         Flag text based on font size. Useful to detect
         super/subscripts. Adds <s></s> around flagged text.
-    line_close_tol : int, optional (default: 2)
+    strip_text : str, optional (default: '')
+        Characters that should be stripped from a string before
+        assigning it to a cell.
+    line_tol : int, optional (default: 2)
         Tolerance parameter used to merge close vertical and horizontal
         lines.
-    joint_close_tol : int, optional (default: 2)
+    joint_tol : int, optional (default: 2)
         Tolerance parameter used to decide whether the detected lines
         and points lie close to each other.
     threshold_blocksize : int, optional (default: 15)
@@ -70,17 +73,15 @@ class Lattice(BaseParser):
         Number of times for erosion/dilation is applied.
 
         For more information, refer `OpenCV's dilate <https://docs.opencv.org/2.4/modules/imgproc/doc/filtering.html#dilate>`_.
-    margins : tuple
-        PDFMiner char_margin, line_margin and word_margin.
-
-        For more information, refer `PDFMiner docs <https://euske.github.io/pdfminer/>`_.
+    resolution : int, optional (default: 300)
+        Resolution used for PDF to PNG conversion.
 
     """
     def __init__(self, table_areas=None, process_background=False,
                  line_size_scaling=15, copy_text=None, shift_text=['l', 't'],
-                 split_text=False, flag_size=False, line_close_tol=2,
-                 joint_close_tol=2, threshold_blocksize=15, threshold_constant=-2,
-                 iterations=0, margins=(1.0, 0.5, 0.1), **kwargs):
+                 split_text=False, flag_size=False, strip_text='', line_tol=2,
+                 joint_tol=2, threshold_blocksize=15, threshold_constant=-2,
+                 iterations=0, resolution=300, **kwargs):
         self.table_areas = table_areas
         self.process_background = process_background
         self.line_size_scaling = line_size_scaling
@@ -88,12 +89,13 @@ class Lattice(BaseParser):
         self.shift_text = shift_text
         self.split_text = split_text
         self.flag_size = flag_size
-        self.line_close_tol = line_close_tol
-        self.joint_close_tol = joint_close_tol
+        self.strip_text = strip_text
+        self.line_tol = line_tol
+        self.joint_tol = joint_tol
         self.threshold_blocksize = threshold_blocksize
         self.threshold_constant = threshold_constant
         self.iterations = iterations
-        self.char_margin, self.line_margin, self.word_margin = margins
+        self.resolution = resolution
 
     @staticmethod
     def _reduce_index(t, idx, shift_text):
@@ -214,7 +216,7 @@ class Lattice(BaseParser):
             '-sDEVICE=png16m',
             '-o',
             self.imagename,
-            '-r600',
+            '-r{}'.format(self.resolution),
             self.filename
         ]
         gs = get_executable()
@@ -283,9 +285,9 @@ class Lattice(BaseParser):
         rows.extend([tk[1], tk[3]])
         # sort horizontal and vertical segments
         cols = merge_close_lines(
-            sorted(cols), line_close_tol=self.line_close_tol)
+            sorted(cols), line_tol=self.line_tol)
         rows = merge_close_lines(
-            sorted(rows, reverse=True), line_close_tol=self.line_close_tol)
+            sorted(rows, reverse=True), line_tol=self.line_tol)
         # make grid using x and y coord of shortlisted rows and cols
         cols = [(cols[i], cols[i + 1])
                 for i in range(0, len(cols) - 1)]
@@ -302,7 +304,7 @@ class Lattice(BaseParser):
 
         table = Table(cols, rows)
         # set table edges to True using ver+hor lines
-        table = table.set_edges(v_s, h_s, joint_close_tol=self.joint_close_tol)
+        table = table.set_edges(v_s, h_s, joint_tol=self.joint_tol)
         # set table border edges to True
         table = table.set_border()
         # set spanning cells to True
@@ -315,7 +317,7 @@ class Lattice(BaseParser):
             for t in self.t_bbox[direction]:
                 indices, error = get_table_index(
                     table, t, direction, split_text=self.split_text,
-                    flag_size=self.flag_size)
+                    flag_size=self.flag_size, strip_text=self.strip_text)
                 if indices[:2] != (-1, -1):
                     pos_errors.append(error)
                     indices = Lattice._reduce_index(table, indices, shift_text=self.shift_text)
@@ -348,8 +350,8 @@ class Lattice(BaseParser):
 
         return table
 
-    def extract_tables(self, filename, suppress_stdout=False):
-        self._generate_layout(filename)
+    def extract_tables(self, filename, suppress_stdout=False, layout_kwargs={}):
+        self._generate_layout(filename, layout_kwargs)
         if not suppress_stdout:
             logger.info('Processing {}'.format(os.path.basename(self.rootname)))
 
